@@ -1,5 +1,6 @@
+from __future__ import print_function
 from django.conf import settings
-__version__ = '0.3.2'
+__version__ = '0.4.0'
 
 POST_MORTEM = getattr(settings, 'POST_MORTEM', False)
 DEBUG = getattr(settings, 'DEBUG', False)
@@ -13,6 +14,6 @@ if DEBUG and POST_MORTEM == True:
         except ImportError:
             import pdb as ipdb
         p = ipdb
-        print >> sys.stderr, "Exception occured: %s, %s" % (exc_type, exc_value)
+        print('Exception occured: {}, {}'.format(exc_type, exc_value), file=sys.stderr)
         p.post_mortem(tb)
     debug.technical_500_response = runpdb
